@@ -3,7 +3,7 @@ import sys
 import inspect
 import argparse
 from inspect import isfunction
-from . import QproDefaultConsole, QproErrorString, user_lang
+from . import QproDefaultConsole, QproErrorString, _lang
 
 
 def str2bool(v):
@@ -19,7 +19,11 @@ def str2bool(v):
 
 class Commander:
     def __init__(
-        self, name: str, seg_flag: bool = False, custom_complete: bool = False, non_complete: bool = False
+        self,
+        name: str,
+        seg_flag: bool = False,
+        custom_complete: bool = False,
+        non_complete: bool = False,
     ):
         """
         QuickProject的Commander类，帮助快速构建一个命令工具
@@ -29,7 +33,15 @@ class Commander:
         self.name = name
         self.non_complete = non_complete
         self.command_table = {}
-        self.fig_table = [{"name": "--help", "description": "获取帮助", "options": [{"name": "--hidden", "description": "显示隐藏命令"}]}]
+        self.fig_table = [
+            {
+                "name": "--help",
+                "description": _lang["GetHelp"],
+                "options": [
+                    {"name": "--hidden", "description": _lang["ShowHiddenCommand"]}
+                ],
+            }
+        ]
         self.custom_complete_table = {}
         self.seg_flag = seg_flag
 
@@ -73,7 +85,7 @@ class Commander:
     def command(self, hidden: bool = False):
         def wrapper(func):
             if not isfunction(func):
-                raise TypeError(f"{func} not a function")
+                raise TypeError(f"{func} " + _lang["NotFunction"])
             param_doc = (
                 {
                     i[0].strip(): i[1].strip()
@@ -99,7 +111,7 @@ class Commander:
                 "options": [],
             }
             if func_name in self.command_table:
-                raise Exception(f"{func} already in command table")
+                raise Exception(f"{func} " + _lang["CommandAlreadyExists"])
             for arg in func_analyser.parameters.values():
                 if arg.name.startswith("_"):  # 忽略私有参数
                     continue
@@ -146,9 +158,8 @@ class Commander:
                         QproDefaultConsole.print(
                             QproErrorString,
                             f"{func_name}:",
-                            '"list" 类型不可以有默认值'
-                            if user_lang == "zh"
-                            else '"list" type can not have default value',
+                            '"list"',
+                            _lang["CantHaveDefaultValue"],
                         )
                         return
                     _kw = {"required": False, "type": _type, "default": _default}
@@ -231,14 +242,14 @@ class Commander:
             show_edge=False,
             row_styles=["none", "dim"],
             box=SIMPLE_HEAVY,
-            title=f"[bold underline]帮助 HELP[/bold underline]\n",
+            title=f"[bold underline]{_lang['Help']}[/bold underline]\n",
         )
-        table.add_column("子命令\nSub Command", justify="center")
-        table.add_column("描述\nDescription", justify="center")
+        table.add_column(_lang["SubCommand"], justify="center")
+        table.add_column(_lang["Description"], justify="center")
         if has_requir:
-            table.add_column("必填参数\nRequired Args", justify="center")
+            table.add_column(_lang["RequiredArgs"], justify="center")
         if has_option:
-            table.add_column("可选参数\nOptionnal Args", justify="center")
+            table.add_column(_lang["OptionnalArgs"], justify="center")
         for function in self.command_table:
             if self.command_table[function]["hidden"] and not shown_hidden:
                 continue
@@ -286,13 +297,11 @@ class Commander:
                 f"{i}:{self.command_table[i]['func'].__doc__.strip().split(':param')[0].strip().replace(' ', '_') if self.command_table[i]['func'].__doc__ else 'NONE'}"
                 for i in self.command_table
             ]
-            return "\n".join(
-                ls + ["--help:应用帮助" if user_lang == "zh" else "--help:Application help"]
-            )
+            return "\n".join(ls + ["--help:" + _lang["Help"]])
         call_func = route_path[0]
         has_args = [i.strip().strip("--") for i in route_path[1:]]
         if call_func not in self.command_table:
-            return "错误:无该命令" if user_lang != "zh" else "ERROR:No such command"
+            return _lang["NoSuchCommand"]
         call_analyser = self.command_table[call_func]["analyser"]
         param_doc = self.command_table[call_func]["param_doc"]
         res = []
@@ -301,11 +310,9 @@ class Commander:
                 continue
             if arg.default != arg.empty:
                 res.append(
-                    f'--{arg.name}:{param_doc[arg.name].replace(" ", "_") if arg.name in param_doc else "No Description" if user_lang != "zh" else "无参数描述"}'
+                    f'--{arg.name}:{param_doc[arg.name].replace(" ", "_") if arg.name in param_doc else _lang["NoDescription"]}'
                 )
-        return "\n".join(
-            res + ["--help:应用帮助" if user_lang == "zh" else "--help:Application help"]
-        )
+        return "\n".join(res + ["--help:" + _lang["Help"]])
 
     def _fig_complete_(self):
         import json
@@ -313,8 +320,8 @@ class Commander:
         table = self.fig_table.copy()
         if self.non_complete:
             for item in table:
-                _item = self.command_table.get(item['name'], None)
-                if _item and _item['hidden']:
+                _item = self.command_table.get(item["name"], None)
+                if _item and _item["hidden"]:
                     table.remove(item)
         return json.dumps(table, ensure_ascii=False, indent=4)
 
@@ -327,23 +334,16 @@ class Commander:
             elif sys.argv[1] == "--qrun-fig-complete":
                 return print(self._fig_complete_())
             if sys.argv[1] == "--help":
-                return self.help('--hidden' in sys.argv)
+                return self.help("--hidden" in sys.argv)
         try:
             func_name = sys.argv[1]
             sys.argv = sys.argv[:1] + sys.argv[2:]
             if func_name not in self.command_table:
                 return QproDefaultConsole.print(
-                    QproErrorString,
-                    f'"{func_name}"'
-                    + (":无该命令" if user_lang != "zh" else ":No such command"),
+                    QproErrorString, f'"{func_name}":' + _lang["NoSuchCommand"]
                 )
         except IndexError:
-            return QproDefaultConsole.print(
-                QproErrorString,
-                "至少输入一个子命令!"
-                if user_lang == "zh"
-                else "Input at least one sub command!",
-            )
+            return QproDefaultConsole.print(QproErrorString, _lang["NoCommandInput"])
         else:
             func_info = self.command_table[func_name]
             args = func_info["parser"].parse_args()
@@ -352,7 +352,7 @@ class Commander:
                     func_info["pre_call"](**{i[0]: i[1] for i in args._get_kwargs()})
                 return func_info["func"](**{i[0]: i[1] for i in args._get_kwargs()})
             except KeyboardInterrupt:
-                return QproDefaultConsole.print(QproErrorString, "用户中断")
+                return QproDefaultConsole.print(QproErrorString, _lang["UserInterrupt"])
             except:
                 QproDefaultConsole.print_exception()
                 exit(1)
@@ -370,15 +370,12 @@ class Commander:
             func_name = func_name.replace("_", "-")
         if func_name not in self.command_table:
             return QproDefaultConsole.print(
-                QproErrorString,
-                f"{func_name} 未被注册!"
-                if user_lang == "zh"
-                else f"{func_name} not registered!",
+                QproErrorString, f'"{func_name}":' + _lang["NoSuchCommand"]
             )
         try:
             return self.command_table[func_name]["func"](*args, **kwargs)
         except KeyboardInterrupt:
-            return QproDefaultConsole.print(QproErrorString, "用户中断")
+            return QproDefaultConsole.print(QproErrorString, _lang["UserInterrupt"])
         except Exception:
             return QproDefaultConsole.print_exception()
 
@@ -392,9 +389,7 @@ class Commander:
         if func_name not in self.command_table:
             return QproDefaultConsole.print(
                 QproErrorString,
-                f"{func_name} 未被注册!"
-                if user_lang == "zh"
-                else f"{func_name} not registered!",
+                f'"{func_name}":' + _lang["NoSuchCommand"],
             )
         self.command_table[func_name]["pre_call"] = pre_call
 
@@ -414,20 +409,15 @@ class Commander:
 
         if self.non_complete:
             for item in project_subcommands:
-                _item = self.command_table.get(item['name'], None)
-                if _item and _item['hidden']:
+                _item = self.command_table.get(item["name"], None)
+                if _item and _item["hidden"]:
                     project_subcommands.remove(item)
 
-        if (
-            os.path.exists("complete")
-            and os.path.isdir("complete")
-        ):
+        if os.path.exists("complete") and os.path.isdir("complete"):
             if _ask(
                 {
                     "type": "confirm",
-                    "message": "complete文件夹已存在,是否覆盖?"
-                    if user_lang == "zh"
-                    else "complete folder already exists, overwrite?",
+                    "message": _lang["OverwriteCompleteDir"],
                     "default": False,
                 }
             ):
@@ -469,15 +459,19 @@ class Commander:
         )"""
                 sub_cmd_opts = []
                 for arg in sub_cmd["args"]:
-                    if 'suggestions' in arg:
-                        for i in arg['suggestions']:
-                            sub_cmd_opts.append(f"{i['name']}:'{i.get('description', i['name'])}'")
+                    if "suggestions" in arg:
+                        for i in arg["suggestions"]:
+                            sub_cmd_opts.append(
+                                f"{i['name']}:'{i.get('description', i['name'])}'"
+                            )
                     elif arg["name"].startswith("-"):
                         sub_cmd_opts.append(f"{arg['name']}:'{arg['description']}'")
                 for opt in sub_cmd["options"]:
-                    if 'suggestions' in opt:
-                        for i in opt['suggestions']:
-                            sub_cmd_opts.append(f"{i['name']}:'{i.get('description', i['name'])}'")
+                    if "suggestions" in opt:
+                        for i in opt["suggestions"]:
+                            sub_cmd_opts.append(
+                                f"{i['name']}:'{i.get('description', i['name'])}'"
+                            )
                     elif opt["name"].startswith("-"):
                         sub_cmd_opts.append(f"{opt['name']}:'{opt['description']}'")
                 cur_args = cur_args.replace("__sub_cmd__", sub_cmd["name"])
@@ -505,7 +499,7 @@ class Commander:
         if _ask(
             {
                 "type": "confirm",
-                "message": "是否安装至fig?" if user_lang == "zh" else "Install to fig?",
+                "message": _lang["InstallToFig"],
                 "default": False,
             }
         ):
